import numpy as np
import h5py

from util.util import get_grid_values_all


def acspo_validate(oper_file, cspp_file):

    h5f_oper = h5py.File(oper_file, 'r')
    h5f_cspp = h5py.File(cspp_file, 'r')

    lon_cspp = get_grid_values_all(h5f_cspp, 'lon')
    lat_cspp = get_grid_values_all(h5f_cspp, 'lat')
    print('cspp shape: ', lat_cspp.shape)
    c_idx = lat_cspp.shape[1] // 2
    cntr_lon_cspp = lon_cspp[:, c_idx]
    cntr_lat_cspp = lat_cspp[:, c_idx]

    sst_cspp = get_grid_values_all(h5f_cspp, 'sea_surface_temperature')[0, ]
    l2p_flags_cspp = get_grid_values_all(h5f_cspp, 'l2p_flags')[0, ]

    lon_oper = get_grid_values_all(h5f_oper, 'lon')
    lat_oper = get_grid_values_all(h5f_oper, 'lat')
    cntr_lon_oper = lon_oper[:, c_idx]
    cntr_lat_oper = lat_oper[:, c_idx]
    print('oper shape: ', lat_oper.shape)
    sst_oper = get_grid_values_all(h5f_oper, 'sea_surface_temperature')[0, ]
    l2p_flags_oper = get_grid_values_all(h5f_oper, 'l2p_flags')[0, ]

    # generate a ndarray of boolean
    cspp_clear = (l2p_flags_cspp & (1 << 15)) != 0
    oper_clear = (l2p_flags_oper & (1 << 15)) != 0

    start_idx_oper = -1
    stop_idx_oper = -1
    start_idx_cspp = -1
    stop_idx_cspp = -1

    for k in range(len(cntr_lat_oper)):
        c_a = np.isclose(cntr_lat_oper[k], cntr_lat_cspp)
        if np.size(np.nonzero(c_a)[0]) == 1:
            if start_idx_oper == -1:
                start_idx_oper = k
                start_idx_cspp = np.nonzero(c_a)[0][0]
            else:
                stop_idx_oper = k
                stop_idx_cspp = np.nonzero(c_a)[0][0]

    print('oper start, stop ', start_idx_oper, stop_idx_oper)
    print('cspp start, stop ', start_idx_cspp, stop_idx_cspp)

    lon_cspp = lon_cspp[start_idx_cspp:stop_idx_cspp, :].flatten()
    lat_cspp = lat_cspp[start_idx_cspp:stop_idx_cspp, :].flatten()
    lon_oper = lon_oper[start_idx_oper:stop_idx_oper, :].flatten()
    lat_oper = lat_oper[start_idx_oper:stop_idx_oper, :].flatten()

    print(np.size(lon_cspp), np.size(lon_oper))
    print(np.size(lat_cspp), np.size(lat_oper))

    print(np.sum(np.isclose(lon_cspp, lon_oper, rtol=0.001)))
    print(np.sum(np.isclose(lat_cspp, lat_oper, rtol=0.001)))

    sst_cspp = sst_cspp[start_idx_cspp:stop_idx_cspp, :].flatten()
    sst_oper = sst_oper[start_idx_oper:stop_idx_oper, :].flatten()

    both_valid = np.invert(np.isnan(sst_cspp)) & np.invert(np.isnan(sst_oper))
    print('number of valid sst in both: ', np.sum(both_valid))

    print(np.sum(np.isclose(sst_cspp[both_valid], sst_oper[both_valid], rtol=0.001)))
    # print(np.histogram((sst_cspp[both_valid] - sst_oper[both_valid]), bins=10))



